/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.core.operator.filter.predicate;

import org.apache.pinot.common.request.context.predicate.Predicate;


public abstract class BasePredicateEvaluator implements PredicateEvaluator {
  protected final Predicate _predicate;

  protected BasePredicateEvaluator(Predicate predicate) {
    _predicate = predicate;
  }

  @Override
  public Predicate getPredicate() {
    return _predicate;
  }

  @Override
  public Predicate.Type getPredicateType() {
    return getPredicate().getType();
  }

  @Override
  public final boolean isExclusive() {
    return getPredicateType().isExclusive();
  }

  @Override
  public int getNumMatchingDictIds() {
    return getMatchingDictIds().length;
  }

  @Override
  public int getNumNonMatchingDictIds() {
    return getNonMatchingDictIds().length;
  }
}
